@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.22 2004/03/09 23:13:31 hadess Exp $ */
+/* $Id: proclist.c,v 1.25 2005/12/12 09:38:11 jamesh Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proclist.h>
@@ -59,7 +60,7 @@ glibtop_init_proclist_p (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t real_which, int64_t arg)
+			gint64 real_which, gint64 arg)
 {
 	struct kinfo_proc *pinfo;
 	unsigned *pids = NULL;
@@ -67,7 +68,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	int i,j;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROCLIST), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	which = (int)(real_which & GLIBTOP_KERN_PROC_MASK);
